@@ -11,16 +11,14 @@
 #include "libkhotkeysfwd.h"
 #include "triggers/triggers.h"
 
-
 /**
  * @author Michael Jansen <kde@michael-jansen.biz>
  */
 class TriggerWidgetBase : public HotkeysWidgetIFace
-    {
+{
     Q_OBJECT
 
 public:
-
     /**
      * Default constructor
      */
@@ -30,15 +28,19 @@ public:
      */
     virtual ~TriggerWidgetBase();
 
-    virtual KHotKeys::Trigger * trigger() { return _trigger; }
-    virtual const KHotKeys::Trigger * trigger() const { return _trigger; }
+    virtual KHotKeys::Trigger *trigger()
+    {
+        return _trigger;
+    }
+    virtual const KHotKeys::Trigger *trigger() const
+    {
+        return _trigger;
+    }
 
 protected:
-
-    TriggerWidgetBase( KHotKeys::Trigger *trigger, QWidget *parent = nullptr );
+    TriggerWidgetBase(KHotKeys::Trigger *trigger, QWidget *parent = nullptr);
 
     KHotKeys::Trigger *_trigger;
-
-    };
+};
 
 #endif /* #ifndef TRIGGER_WIDGET_BASE_H */
